Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(95)

Unified Diff: scripts/slave/recipe_modules/filter/example.py

Issue 473313002: Adds handling of 'Found dependency (all)' to filter (Closed) Base URL: https://chromium.googlesource.com/chromium/tools/build.git@master
Patch Set: Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: scripts/slave/recipe_modules/filter/example.py
diff --git a/scripts/slave/recipe_modules/filter/example.py b/scripts/slave/recipe_modules/filter/example.py
index d2bb3e3e382015c19f279d071b6ee9eeb8486c83..83c66b0284ba5beb44aff20ec877297fd6af3d53 100644
--- a/scripts/slave/recipe_modules/filter/example.py
+++ b/scripts/slave/recipe_modules/filter/example.py
@@ -60,7 +60,17 @@ def GenTests(api):
api.json.output({'status': 'Found dependency',
'targets': []})))
- # Analyze returns matching tests.
+ # Analyze returns matching tests while matching all.
+ yield (api.test('analyzes_matches_all_exes') +
+ api.properties(matching_exes=['foo', 'bar']) +
+ api.properties(example_matching_exes=['foo']) +
+ api.properties(example_result=1) +
+ api.override_step_data(
+ 'analyze',
+ api.json.output({'status': 'Found dependency (all)',
+ 'targets': ['foo']})))
+
+ # Analyze matches all and returns matching tests.
yield (api.test('analyzes_matches_exes') +
api.properties(matching_exes=['foo', 'bar']) +
api.properties(example_matching_exes=['foo']) +

Powered by Google App Engine
This is Rietveld 408576698